@@ -12,11 +12,8 @@ import gc
 import random
 from string import punctuation
 import argparse
-
-parser = argparse.ArgumentParser(description='manual to this script')
-current_path = os.path.dirname(__file__)
-if len(current_path)==0:
-    current_path="."
+from string import punctuation
+import re
 
 def wrapNebula2Df(nebulaObj):
     '''将platoDB查询到的对象转为df'''
@@ -319,6 +316,27 @@ def existEdge(headType,headIdAttr,headIdVal,tailType,tailIdAttr,tailIdVal,edgeTy
         return True
     return False
 
+def nlpPreprocessAttr(gClient,nodeType,nodeIdAttrName,nodeAttrName,tabuStr=""):
+    '''图数据库属性的文本预处理'''
+    tabuStr="\\/'"+tabuStr+punctuation
+    nodeSysIdDf=wrapNebula2Df(gClient.execute_query("LOOKUP ON {nodeType} WHERE {nodeType}.{nodeIdAttr}!='不可能的名字'\
+                                                        YIELD {nodeType}.{nodeAttr} AS tgtAttr".format(nodeType=nodeType,
+                                                                                            nodeIdAttrName=nodeIdAttrName,
+                                                                                            nodeAttrName=nodeAttrName)))
+    if nodeSysIdDf.shape[0]>0:
+        nodeSysIdDf["tgtAttr"]=nodeSysIdDf["tgtAttr"].apply(lambda row:re.sub("["+tabuStr+"]","",row))
+        nodeSysIdAttrList=nodeSysIdDf.loc[:,["VertexID","tgtAttr"]].values.tolist()
+        for nodeSysId,nodeAttrVal in nodeSysIdAttrList:
+            gClient.execute_query("UPDATE VERTEX {nodeSysId} SET {nodeType}.{nodeAttr}='{nodeVal}'".format(
+                                                                                                            nodeSysId=nodeSysId,
+                                                                                                            nodeType=nodeType,
+                                                                                                            nodeAttr=nodeAttrName,
+                                                                                                            nodeVal=nodeAttrVal
+                                                                                                        ))
+        
+        
+    
+
 def addTokenForEntities(gClient,gDBName,nodeIdAttrList,tabuList=[],projectName="",email=""):
     '''构建实体的token实体'''
     if "csv2platodb" not in os.listdir("."):
@@ -349,15 +367,16 @@ def addTokenForEntities(gClient,gDBName,nodeIdAttrList,tabuList=[],projectName="
             for tgtNameTokenItem in tgtNameItem:
                 if tgtNameTokenItem not in tabuList:
                     tokenInfoList.append({"Name":tgtNameTokenItem})
-                srcTokenPairList.append({"headEntity":tgtNameTokenItem,"tailEntity":tgtNameTokenItem})
+                # print({"headEntity":tgtNameItem,"tailEntity":tgtNameTokenItem})
+                srcTokenPairList.append({"headEntity":tgtNameItem,"tailEntity":tgtNameTokenItem})
         srcTokenPairDf=pd.DataFrame(srcTokenPairList)
         tokenInfoDf=pd.DataFrame(tokenInfoList)
             
-        tokenInfoDf.to_csv(current_path+"/csv2platodb/{}/tokenInfo_{}.csv".format(projectName,nodeType),index=None)
-        srcTokenPairDf.to_csv(current_path+"/csv2platodb/{}/consistOfRel_{}.csv".format(projectName,nodeType),index=None)
+        tokenInfoDf.to_csv("./csv2platodb/{}/tokenInfo_{}.csv".format(projectName,nodeType),index=None)
+        srcTokenPairDf.to_csv("./csv2platodb/{}/consistOfRel_{}.csv".format(projectName,nodeType),index=None)
         
         schemaVertex.append({ 
-                                "file_name":"tokenInfo_{}.csv".format(projectName,nodeType),
+                                "file_name":"tokenInfo_{}.csv".format(nodeType),
                                 "node_type":"Token",
                                 "id_col":"Name", 
                                 "csv2plato_attr_map":{ 
@@ -368,7 +387,7 @@ def addTokenForEntities(gClient,gDBName,nodeIdAttrList,tabuList=[],projectName="
                                 }
                             })
         schemaEdge.append({
-                                "file_name":"consistOfRel_{}.csv".format(projectName,nodeType),
+                                "file_name":"consistOfRel_{}.csv".format(nodeType),
                                 "edge_type":"consistOf",
                                 "src_type":nodeType,
                                 "tgt_type":"Token",
@@ -387,7 +406,7 @@ def addTokenForEntities(gClient,gDBName,nodeIdAttrList,tabuList=[],projectName="
     if len(email)==0:
         VESchema.pop("email")
     
-    with open(current_path+"/csv2platodb/{}/rawSchema.json".format(projectName,nodeType),"w+",encoding="utf8") as VESchemaFile:
+    with open("./csv2platodb/{}/rawSchema.json".format(projectName,nodeType),"w+",encoding="utf8") as VESchemaFile:
         json.dump(VESchema,VESchemaFile)
     
     print("本地文件生成")
